@@ -211,7 +211,17 @@ class CloudFrontToApiGateway(
         :summary: Constructs a new instance of the CloudFrontToApiGateway class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToApiGateway.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToApiGatewayProps(
@@ -274,7 +284,15 @@ class CloudFrontToApiGatewayProps:
         if isinstance(cloud_front_logging_bucket_props, dict):
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToApiGatewayProps.__init__)
+            def stub(
+                *,
+                existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument existing_api_gateway_obj", value=existing_api_gateway_obj, expected_type=type_hints["existing_api_gateway_obj"])
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
